<?php 

remove_action( 'wp_head', 'ebor_framework_load_favicons' );

if(!( function_exists( 'ebor_modify_read_more_link' ) )){
	function ebor_modify_read_more_link() {
		return '<a class="more-link" href="' . get_permalink() . '">'. esc_html__('Read More','acomb') .'</a>';
	}
	add_filter( 'the_content_more_link', 'ebor_modify_read_more_link' );
}

/**
 * Add a clearfix to the end of the_content()
 */
if(!( function_exists( 'ebor_add_clearfix' ) )){ 
	function ebor_add_clearfix( $content ) { 
		$content = '<div class="post-content">'. $content . '</div><div class="clearfix"></div>';
	    return $content;
	}
	add_filter( 'the_content', 'ebor_add_clearfix' ); 
}

/**
 * Modify excerpt more
 */
if(!( function_exists( 'ebor_excerpt_more' ) )){
	function ebor_excerpt_more( $more ) {
		return '...';
	}
	add_filter('excerpt_more', 'ebor_excerpt_more');
}

if(!( function_exists( 'ebor_wpa_category_nav_class' ) )){
	function ebor_wpa_category_nav_class( $classes, $item ){
	    if( 'category' == $item->object ){
	        $classes[] = 'cat-menu-' . $item->object_id;
	    }
	    return $classes;
	}
	add_filter( 'nav_menu_css_class', 'ebor_wpa_category_nav_class', 10, 2 );
}

/**
 * Add additional settings to gallery shortcode
 */
if(!( function_exists( 'ebor_add_gallery_settings' ) )){ 
	function ebor_add_gallery_settings(){
	?>
	
		<script type="text/html" id="tmpl-acomb-gallery-setting">
			<h3>acomb Theme Gallery Settings</h3>
			<label class="setting">
				<span><?php esc_html_e( 'Gallery Layout', 'acomb' ); ?></span>
				<select data-setting="layout">
					<option value="default">Default Layout</option>
					<option value="slider">Acomb Slider</option>        
					<option value="lightbox">Acomb Lightbox Gallery</option>
				</select>
			</label>
		</script>
	
		<script>
			jQuery(document).ready(function(){
				jQuery.extend(wp.media.gallery.defaults, { layout: 'default' });
				
				wp.media.view.Settings.Gallery = wp.media.view.Settings.Gallery.extend({
					template: function(view){
					  return wp.media.template('gallery-settings')(view)
					       + wp.media.template('acomb-gallery-setting')(view);
					}
				});
			});
		</script>
	  
	<?php
	}
	add_action( 'print_media_templates', 'ebor_add_gallery_settings' );
}


/**
 * Custom gallery shortcode
 *
 * Filters the standard WordPress gallery shortcode.
 *
 * @since 1.0.0
 */
if(!( function_exists( 'ebor_post_gallery' ) )){
	function ebor_post_gallery( $output, $attr ) {
		
		global $post, $wp_locale;
	
	    static $instance = 0;
	    $instance++;
	
	    // We're trusting author input, so let's at least make sure it looks like a valid orderby statement
	    if ( isset( $attr['orderby'] ) ) {
	        $attr['orderby'] = sanitize_sql_orderby( $attr['orderby'] );
	        if ( !$attr['orderby'] )
	            unset( $attr['orderby'] );
	    }
	
	    extract(shortcode_atts(array(
	        'order'      => 'ASC',
	        'orderby'    => 'menu_order ID',
	        'id'         => $post->ID,
	        'itemtag'    => 'div',
	        'icontag'    => 'dt',
	        'captiontag' => 'dd',
	        'columns'    => 3,
	        'size'       => 'large',
	        'include'    => '',
	        'exclude'    => '',
	        'layout'     => ''
	    ), $attr));
	
	    $id = intval($id);
	    if ( 'RAND' == $order )
	        $orderby = 'none';
	
	    if ( !empty($include) ) {
	        $include = preg_replace( '/[^0-9,]+/', '', $include );
	        $_attachments = get_posts( array('include' => $include, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	
	        $attachments = array();
	        foreach ( $_attachments as $key => $val ) {
	            $attachments[$val->ID] = $_attachments[$key];
	        }
	    } elseif ( !empty($exclude) ) {
	        $exclude = preg_replace( '/[^0-9,]+/', '', $exclude );
	        $attachments = get_children( array('post_parent' => $id, 'exclude' => $exclude, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	    } else {
	        $attachments = get_children( array('post_parent' => $id, 'post_status' => 'inherit', 'post_type' => 'attachment', 'post_mime_type' => 'image', 'order' => $order, 'orderby' => $orderby) );
	    }
	
	    if ( empty($attachments) ) {
	        return '';
	    }
	
	    if ( is_feed() ) {
	        $output = "\n";
	        foreach ( $attachments as $att_id => $attachment )
	            $output .= wp_get_attachment_link($att_id, $size, true) . "\n";
	        return $output;
	    }
	    
	    /**
	     * Return Lightbox Layout
	     */
	    if( $layout == 'lightbox' ){
			
			$i = 0;
			$l = 0;
		    $output = '<div class="tiles clearfix"><div class="items light-gallery">';
		
		    foreach ( $attachments as $id => $attachment ) {
		        $link = isset($attr['link']) && 'file' == $attr['link'] ? wp_get_attachment_url( $id, 'full', false, false ) : wp_get_attachment_url( $id, 'full', true, false );
		        $i++;
		        $l++;
		        $titles = get_post( $id );
		        
		        if( 1 == $l ){
		        	$class = 'col-md-4';
		        } elseif( 2 == $l ){
		        	$class = 'col-md-8';
		        } else {
		        	$class = 'col-md-6';
		        }
		        
		        if( 4 == $l ){
		        	$l = 0;	
		        }
		        
		        $output .= '
			        <div class="item col-xs-12 col-sm-6 '. esc_attr( $class ) .'">
				        <figure class="overlay">
					        <a class="lgitem background-image" href="'. esc_url( $link ) .'" data-sub-html="#caption'. esc_attr( $id ) .'">
					       		'. wp_get_attachment_image( $id, 'large' ) .'
					        </a>
				        </figure>
				        <div id="caption'. esc_attr( $id ) .'" class="hidden">
				       		<h3>'. esc_html( $titles->post_title ) .'</h3>
				        	<p>'. esc_html( $titles->post_excerpt ) .'</p>
				        </div>
			        </div>
		        ';

		    }
		
		    $output .= "</div></div>";
		    
		    return $output;
	    }
	    
	    /**
	     * Return Slider Layout
	     */
	    if( $layout == 'slider' ){
	    	$output = '<div class="post-slider basic-slider owl-carousel">';
	    		foreach ( $attachments as $id => $attachment ) {
	    		    $output .= '<div class="item">'. wp_get_attachment_image( $id, 'large' ) .'</div>';
	    		} 
	    	$output .= '</div>';
	    	return $output;
	    }
	    
	}
	add_filter( 'post_gallery', 'ebor_post_gallery', 10, 2 );
}