<?php 

/**
 * Init theme options
 * Certain theme options need to be written to the database as soon as the theme is installed.
 * This is either for the enqueues in ebor-framework, or to override the default image sizes in WooCommerce.
 * Either way this function is only called when the theme is first activated, de-activating and re-activating the theme will result in these options returning to defaults.
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_init_theme_options' ) )){
	/**
	 * Hook in on activation
	 */
	global $pagenow;

	function ebor_init_theme_options() {

		$catalog = array(
			'width' 	=> '440',	// px
			'height'	=> '650',	// px
			'crop'		=> 1 		// true
		);
	
		$single = array(
			'width' 	=> '600',	// px
			'height'	=> '600',	// px
			'crop'		=> 1 		// true
		);
	
		$thumbnail = array(
			'width' 	=> '113',	// px
			'height'	=> '113',	// px
			'crop'		=> 1 		// false
		);
	
		// Image sizes
		update_option( 'shop_catalog_image_size', $catalog );
		update_option( 'shop_single_image_size', $single );
		update_option( 'shop_thumbnail_image_size', $thumbnail ); 
	
		//Set all options to zero before initialising options for this theme
		$existing_options = get_option( 'ebor_framework_options' );
		if( is_array($existing_options) ){
			foreach ($existing_options as $key => $value) {
				$existing_options[$key] = '0';
			}
			update_option( 'ebor_framework_options', $existing_options );
		}
		
		//Ebor Framework
		$framework_args = array(
			'options'               => '1',
			'metaboxes'             => '1',
			'acomb_widgets'   		=> '1',
		);
		
		update_option( 'ebor_framework_options', $framework_args );
		
	}
	
	/**
	 * Only call this action when we first activate the theme.
	 */
	if ( 
		is_admin() && isset( $_GET['activated'] ) && $pagenow == 'themes.php' ||
		is_admin() && isset( $_GET['theme'] ) && $pagenow == 'customize.php'
	){
		add_action( 'init', 'ebor_init_theme_options', 1 );
	}
}

/**
 * Register the required plugins for this theme.
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_register_required_plugins' ) )){
	function ebor_register_required_plugins() {
		$plugins = array(
			array(
			    'name'      => 'Contact Form 7',
			    'slug'      => 'contact-form-7',
			    'required'  => false,
			    'version' 	=> '3.7.2'
			),
			array(
				'name'     				=> 'Ebor Framework',
				'slug'     				=> 'Ebor-Framework-master',
				'source'   				=> 'https://github.com/tommusrhodus/ebor-framework/archive/master.zip',
				'required' 				=> true,
				'version' 				=> '1.0.0',
				'external_url' 			=> 'https://github.com/tommusrhodus/ebor-framework/archive/master.zip',
			)
		);
		$config = array(
			'is_automatic' => true,
		);
		tgmpa( $plugins, $config );
	}
	add_action( 'tgmpa_register', 'ebor_register_required_plugins' );
}

/**
 * HEX to RGB Converter
 *
 * Converts a HEX input to an RGB array.
 * @param $hex - the inputted HEX code, can be full or shorthand, #ffffff or #fff
 * @since 1.0.0
 * @return string
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_hex2rgb' ) )){
	function ebor_hex2rgb($hex) {
	   $hex = str_replace("#", "", $hex);
	
	   if(strlen($hex) == 3) {
	      $r = hexdec(substr($hex,0,1).substr($hex,0,1));
	      $g = hexdec(substr($hex,1,1).substr($hex,1,1));
	      $b = hexdec(substr($hex,2,1).substr($hex,2,1));
	   } else {
	      $r = hexdec(substr($hex,0,2));
	      $g = hexdec(substr($hex,2,2));
	      $b = hexdec(substr($hex,4,2));
	   }
	   $rgb = array($r, $g, $b);
	   return implode(",", $rgb); // returns the rgb values separated by commas
	   return $rgb; // returns an array with the rgb values
	}
}

if(!( function_exists( 'ebor_get_blog_layouts' ) )){
	function ebor_get_blog_layouts(){
		return array(
			'classic' 				=> 'Classic Blog',
			'classic-sidebar' 		=> 'Classic Blog With Sidebar',
			'masonry' 				=> 'Masonry Blog',
			'masonry-sidebar' 		=> 'Masonry Blog With Sidebar',
			'grid' 					=> 'Grid Blog',
			'grid-sidebar' 			=> 'Grid Blog With Sidebar',
			'full-masonry' 			=> 'Fullwidth First Post Then Masonry Blog',
			'full-masonry-sidebar' 	=> 'Fullwidth First Post Then Masonry Blog With Sidebar',
			'full-grid' 			=> 'Fullwidth First Post Then Grid Blog',
			'full-grid-sidebar' 	=> 'Fullwidth First Post Then Grid Blog With Sidebar',
		);
	}
}

if(!( function_exists( 'ebor_get_slider_layouts' ) )){
	function ebor_get_slider_layouts(){
		return array(
			'carousel' 	=> 'Carousel',
			'slider' 	=> 'Boxed Slider',
			'none' 		=> 'No Slider'
		);
	}
}

if(!( function_exists( 'ebor_get_social_icons' ) )){
	function ebor_get_social_icons(){
		return array(
			'none' 			=> 'None',
			'pinterest' 	=> 'Pinterest',
			'rss' 			=> 'RSS',
			'facebook' 		=> 'Facebook',
			'twitter' 		=> 'Twitter',
			'flickr' 		=> 'Flickr',
			'dribbble' 		=> 'Dribbble',
			'behance' 		=> 'Behance',
			'linkedin' 		=> 'LinkedIn',
			'vimeo' 		=> 'Vimeo',
			'youtube'		=> 'Youtube',
			'skype'			=> 'Skype',
			'tumblr'		=> 'Tumblr',
			'delicious'		=> 'Delicious',
			'500px'			=> '500px',
			'grooveshark'	=> 'Grooveshark',
			'forrst'		=> 'Forrst',
			'digg'			=> 'Digg',
			'blogger'		=> 'Blogger',
			'klout'			=> 'Klout',
			'dropbox'		=> 'Dropbox',
			'github'		=> 'Github',
			'songkick'		=> 'Singkick',
			'posterous'		=> 'Posterous',
			'appnet'		=> 'Appnet',
			'gplus'			=> 'Google Plus',
			'stumbleupon'	=> 'Stumbleupon',
			'lastfm'		=> 'LastFM',
			'spotify'		=> 'Spotify',
			'instagram'		=> 'Instagram',
			'evernote'		=> 'Evernote',
			'paypal'		=> 'Paypal',
			'picasa'		=> 'Picasa',
			'soundcloud'	=> 'Soundcloud'
		);
	}
}

/**
 * Add additional styling options to TinyMCE
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_mce_buttons_2' ) )){
	function ebor_mce_buttons_2( $buttons ) {
	    array_unshift( $buttons, 'styleselect' );
	    return $buttons;
	}
	add_filter( 'mce_buttons_2', 'ebor_mce_buttons_2' );
}

/**
 * Add additional styling options to TinyMCE
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_mce_before_init' ) )){
	function ebor_mce_before_init( $settings ) {
	    $style_formats = array(
	    	array(
	    		'title' 	=> 'Subheading Paragraph',
	    		'selector' 	=> 'p',
	    		'classes' 	=> 'lead',
	    	),
	    	array(
	    		'title' 	=> 'Button',
	    		'selector' 	=> 'a',
	    		'classes' 	=> 'btn',
	    	),
	    );
	    $settings['style_formats'] = json_encode( $style_formats );
	    return $settings;
	}
	add_filter( 'tiny_mce_before_init', 'ebor_mce_before_init' );
}

if(!(function_exists( 'ebor_posts_per_page' ))){
	function ebor_posts_per_page( $query ) {
		
		$haystack = array(
			'full-masonry-sidebar',
			'full-masonry',
			'full-grid-sidebar',
			'full-grid'
		);
		
	    if ( isset($_GET['layout']) && in_array($_GET['layout'], $haystack) && $query->is_main_query() ) {
	    	$perPage = get_option('posts_per_page') + 1;
	        $query->set( 'posts_per_page', (int) $perPage );
	    } 
	    
	    if ( !(isset($_GET['layout'])) && in_array(get_option('blog_layout'), $haystack) && $query->is_main_query() && !(is_admin()) ) {
	    	$perPage = get_option('posts_per_page') + 1;
	        $query->set( 'posts_per_page', (int) $perPage );
	    }
	       
	    return;
	    
	}
	add_action( 'pre_get_posts', 'ebor_posts_per_page' );
}

/**
 * Custom Comment Markup for acomb
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_custom_comment' ) )){
	function ebor_custom_comment($comment, $args, $depth) { 
		$GLOBALS['comment'] = $comment; 
	?>
		
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
		    <div class="user">
		    	<?php echo get_avatar( $comment->comment_author_email, 70 ); ?>
		    </div>
		    <div class="message-inner">
		          <?php printf('<h2>%s</h2>', get_comment_author_link()); ?>
		          <div class="meta">
		          	<span class="date"><?php echo get_comment_date(); ?></span>
		          	 / <span class="reply"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></span>
		          </div>
		        <?php echo wpautop( get_comment_text() ); ?>
		        <?php if ($comment->comment_approved == '0') : ?>
		        <p><em><?php esc_html_e('Your comment is awaiting moderation.', 'acomb') ?></em></p>
		        <?php endif; ?>
		    </div>
	
	<?php }
}