<?php 

/**
 * Build theme metaboxes
 * Uses the cmb metaboxes class found in the ebor framework plugin
 * More details here: https://github.com/WebDevStudios/Custom-Metaboxes-and-Fields-for-WordPress
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if(!( function_exists( 'ebor_custom_metaboxes' ) )){
	function ebor_custom_metaboxes( $meta_boxes ) {
		
		/**
		 * Setup variables
		 */
		$prefix = '_ebor_';
		$social_options = ebor_get_social_icons();
		
		$meta_boxes[] = array(
			'id'			 	=> 'post_layout_metabox',
			'title' 			=> esc_html__( 'Post Layout Options', 'acomb' ),
			'object_types' 		=> array('post', 'page'), // post type
			'context'			=> 'normal',
			'priority' 			=> 'high',
			'show_names' 		=> true, // Show field names on the left
			'fields' => array(
				array(
					'name' => esc_html__( 'Toggle Post Sidebar', 'acomb' ),
					'desc' => esc_html__( "Check to toggle sidebar on/off for this post/page.", 'acomb' ),
					'id'   => $prefix . 'disable_sidebar',
					'type' => 'checkbox',
				)
			)
		);
		
		/**
		 * Social Icons for Users
		 */
		$meta_boxes[] = array(
			'id' 				=> 'social_metabox',
			'title' 			=> esc_html__( 'Social Icons: Click To Add More', 'acomb' ),
			'object_types' 		=> array( 'user' ), // post type
			'context' 			=> 'normal',
			'priority' 			=> 'high',
			'show_names' 		=> true, // Show field names on the left
			'fields' => array(
				array(
				    'id'          => $prefix . 'user_social_icons',
				    'type'        => 'group',
				    'options'     => array(
				        'add_button'    => esc_html__( 'Add Another Icon', 'acomb' ),
				        'remove_button' => esc_html__( 'Remove Icon', 'acomb' ),
				        'sortable'      => true
				    ),
				    'fields' => array(
						array(
							'name' 		=> 'Social Icon',
							'desc' 		=> 'What icon would you like for this team members first social profile?',
							'id' 		=> $prefix . 'social_icon',
							'type' 		=> 'select',
							'options' 	=> $social_options
						),
						array(
							'name' => esc_html__( 'URL for Social Icon', 'acomb' ),
							'desc' => esc_html__( "Enter the URL for Social Icon 1 e.g www.google.com", 'acomb' ),
							'id'   => $prefix . 'social_icon_url',
							'type' => 'text',
						),
				    ),
				),
			)
		);
		
		return $meta_boxes;
	}
	add_filter( 'cmb2_meta_boxes', 'ebor_custom_metaboxes' );
}