<?php 

/**
 * Build theme options
 * Uses the Ebor_Options class found in the ebor-framework plugin
 * Panels are WP 4.0+!!!
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if( class_exists( 'Ebor_Options' ) ){
	$ebor_options = new Ebor_Options;
	
	//Vars
	$theme = wp_get_theme();
	$theme_name = $theme->get( 'Name' );
	$blog_layouts = ebor_get_blog_layouts();
	$slider_layouts = ebor_get_slider_layouts();
	$social_options = ebor_get_social_icons();
	
	$ebor_options->add_section('demo_data_section', 'Import Demo Data', 10, false, '<strong>Please read this before importing demo data via this control:</strong><br /><br />The demo data this will install the fashion demo, please see your download .zip for other demos.<br /><br />Note that this process can take up to 15mins on slower servers, go make a cup of tea. If you havn\'t had a notification in 30mins, use the fallback method outlined in the written documentation.<br /><br />');
	$ebor_options->add_setting('demo_import', 'demo_import', 'Import Demo Data', 'demo_data_section', '', 10);
	
	//Blog Options
	$ebor_options->add_section('blog_layout_section', 'Blog Layout', 20, false);
	$ebor_options->add_setting('select', 'blog_layout', 'Blog Layout', 'blog_layout_section', 'grid-sidebar', 10, $blog_layouts);
	
	//Slider Options
	$ebor_options->add_section('slider_layout_section', 'Slider Layout', 25, false);
	$ebor_options->add_setting('select', 'slider_layout', 'Slider Layout', 'slider_layout_section', 'carousel', 10, $slider_layouts);
	
	//Intro Text Options
	$ebor_options->add_section('intro_text_section', 'Intro Text', 30, false);
	$ebor_options->add_setting('textarea', 'intro_text', 'Intro Text', 'intro_text_section', 'Im John acomb, a freelance photographer specializing in landscape, advertorial and conceptual photography, based in New York. Here you will be able to find my latest and favorite shots.', 15);
	$ebor_options->add_setting('input', 'intro_button_text', 'Intro Button Text', 'intro_text_section', '', 20);
	$ebor_options->add_setting('input', 'intro_button_url', 'Intro Button URL', 'intro_text_section', '', 25);
	
	/**
	 * Instagram API Stuff
	 */
	$ebor_options->add_section('instagram_api_section', $theme_name . ': Instagram Settings', 340, false, '<code>IMPORTANT NOTE:</code> This is the Instagram setup section for the theme, it requires an Access Token and Client ID.<br /><br />Due to how Instagram have set their API you have to register as a developer with Instagram for this to work.<br /><br />For setup details, <a href="https://tommusrhodus.ticksy.com/article/7566" target="_blank">please read this</a>');
	$ebor_options->add_setting('input', 'instagram_token', 'Instagram Access Token', 'instagram_api_section', '', 5);
	$ebor_options->add_setting('input', 'instagram_client', 'Instagram Client ID', 'instagram_api_section', '', 10);
	$ebor_options->add_setting('input', 'instagram_username', 'Instagram Username', 'instagram_api_section', '', 15);
	
	//Colours
	$ebor_options->add_setting('color', 'colour_white', 'White Colour', 'colors', '#ffffff', 5);
	$ebor_options->add_setting('color', 'colour_black', 'Black Colour', 'colors', '#000000', 10);
	$ebor_options->add_setting('color', 'colour_body', 'Body Text Colour', 'colors', '#777777', 15);
	$ebor_options->add_setting('color', 'colour_headings', 'Headings Colour', 'colors', '#333333', 20);
	$ebor_options->add_setting('color', 'colour_light', 'Light Colour', 'colors', '#ECF1F2', 25);
	$ebor_options->add_setting('color', 'colour_highlight', 'Highlight Colour', 'colors', '#0054a6', 30);
	$ebor_options->add_setting('color', 'colour_grey', 'Meta Colour', 'colors', '#f7f7f7', 40);
	
	//Logo
	$ebor_options->add_section('logo_section', 'Logo Settings', 10, false);
	$ebor_options->add_setting('image', 'custom_logo', 'Logo', 'logo_section', EBOR_THEME_DIRECTORY . 'style/img/logo.png', 5);
	$ebor_options->add_setting('select', 'header_strapline', 'Show strapline in header?', 'logo_section', 'yes', 10, array('yes' => 'Yes', 'no' => 'No'));
	
	//Header Icons
	$ebor_options->add_section('header_icons_section', 'Header Settings', 15, false);
	for( $i = 1; $i < 5; $i++ ){
		$ebor_options->add_setting('select', 'header_social_icon_' . $i, 'Header Social Icon ' . $i, 'header_icons_section', 'none', 20 + $i + $i, $social_options);
		$ebor_options->add_setting('input', 'header_social_url_' . $i, 'Header Social URL ' . $i, 'header_icons_section', '', 21 + $i + $i);
	}
	
	$ebor_options->add_setting('select', 'header_search', 'Show search in header?', 'header_icons_section', 'yes', 10, array('yes' => 'Yes', 'no' => 'No'));
	
	$ebor_options->add_section('footer_section', 'Footer Copyright', 260, false);
	$ebor_options->add_setting('textarea', 'copyright', 'Copyright Message - Here you can use *copy* to show a copyright symbol, as well as *current_year* to display the current year.', 'footer_section', '*copy* *current_year* Acomb. By <a href="http://www.tommusrhodus.com">TommusRhodus</a>', 20);
	
	$ebor_options->add_section('custom_css_section', 'Custom CSS', 270, false);
	$ebor_options->add_setting('textarea', 'custom_css', 'Custom CSS', 'custom_css_section', '', 15);
	
	//Promo Boxes
	$ebor_options->add_section('promo_box_section', 'Promo Boxes', 35, false);
	
	$ebor_options->add_setting('image', 'image_link_1_background', 'Promo Box 1 Background', 'promo_box_section', false, 5);
	$ebor_options->add_setting('input', 'image_link_1_title', 'Promo Box 1 Title', 'promo_box_section', '', 10);
	$ebor_options->add_setting('input', 'image_link_1_button_url', 'Promo Box 1 URL', 'promo_box_section', '', 20);
	
	$ebor_options->add_setting('image', 'image_link_2_background', 'Promo Box 2 Background', 'promo_box_section', false, 25);
	$ebor_options->add_setting('input', 'image_link_2_title', 'Promo Box 2 Title', 'promo_box_section', '', 30);
	$ebor_options->add_setting('input', 'image_link_2_button_url', 'Promo Box 2 URL', 'promo_box_section', '', 40);
	
	$ebor_options->add_setting('image', 'image_link_3_background', 'Promo Box 3 Background', 'promo_box_section', false, 45);
	$ebor_options->add_setting('input', 'image_link_3_title', 'Promo Box 3 Title', 'promo_box_section', '', 50);
	$ebor_options->add_setting('input', 'image_link_3_button_url', 'Promo Box 3 URL', 'promo_box_section', '', 60);
	
}