<?php 

/*
	Register Fonts
*/
if(!( function_exists( 'ebor_fonts_url' ) )){
	function ebor_fonts_url(){
	    $font_url = '';
	    
	    /* Translators: If there are characters in your language that are not supported by chosen font(s), translate this to 'off'. Do not translate into your own language. */
	    if ( 'off' !== _x( 'on', 'Google font: on or off', 'acomb' ) ) {
	        $font_url = add_query_arg( 'family', urlencode( 'Roboto:400,500,700,300italic,500italic' ), "//fonts.googleapis.com/css" );
	    }
	    return $font_url;
	}
}

/**
 * Load Scripts
 * Properly Enqueues Scripts & Styles for the theme
 * 
 * @since 1.0.0
 * @author TommusRhodus
 * @package acomb
 */ 
if(!( function_exists( 'ebor_load_scripts' ) )){
	function ebor_load_scripts() {

		$protocol = is_ssl() ? 'https' : 'http';
			
		//Enqueue Styles
		wp_enqueue_style( 'ebor-google-font', ebor_fonts_url() );
		wp_enqueue_style( 'ebor-plugins', EBOR_THEME_DIRECTORY . 'style/css/plugins.css' );	
		wp_enqueue_style( 'fonts-plugins', EBOR_THEME_DIRECTORY . 'style/type/fonts.css' );	
		wp_enqueue_style( 'ebor-style', get_stylesheet_uri() );
		
		//Enqueue Scripts
		wp_enqueue_script( 'jquery-fitvids', EBOR_THEME_DIRECTORY . 'style/js/fitvids.js', array('jquery'), false, true  );
		wp_enqueue_script( 'jquery-goodshare', EBOR_THEME_DIRECTORY . 'style/js/goodshare.js', array('jquery'), false, true  );
		wp_enqueue_script( 'jquery-lightgallery', EBOR_THEME_DIRECTORY . 'style/js/lightgallery.js', array('jquery'), false, true  );
		wp_enqueue_script( 'jquery-masonry', EBOR_THEME_DIRECTORY . 'style/js/masonry.js', array('jquery'), false, true  );
		wp_enqueue_script( 'jquery-owl-carousel', EBOR_THEME_DIRECTORY . 'style/js/owl-carousel.js', array('jquery'), false, true  );
		wp_enqueue_script( 'jquery-spectragram', EBOR_THEME_DIRECTORY . 'style/js/spectragram.js', array('jquery'), false, true  );
		wp_enqueue_script( 'jquery-twitter-fetcher', EBOR_THEME_DIRECTORY . 'style/js/twitter-fetcher.js', array('jquery'), false, true  );
		wp_enqueue_script( 'ebor-scripts', EBOR_THEME_DIRECTORY . 'style/js/scripts.js', array('jquery'), false, true  );
		
		//Enqueue Comments
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
		
		$white 		= get_option( 'colour_white', '#ffffff' );
		$white_rgb 	= ebor_hex2rgb( $white );
		$black 		= get_option( 'colour_black', '#000' );
		$black_rgb 	= ebor_hex2rgb( $black );
		$body 		= get_option( 'colour_body', '#777777' );
		$headings 	= get_option( 'colour_headings', '#333333' );
		$light 		= get_option( 'colour_light', '#ECF1F2' );
		$highlight 	= get_option( 'colour_highlight', '#0054a6' );
		$grey 		= get_option( 'colour_grey', '#f7f7f7' );
		
		$custom_css = '
			body,
			small,
			.social-menu ul li span {
				color: '. $body .';
			}
			h1, 
			h2, 
			h3, 
			h4, 
			h5, 
			h6,
			.btn,
			table th,
			dt,
			.tags a,
			input[type="submit"],
			.social-menu ul,
			.more-link,
			.instafeed > a,
			span[data-scribe],
			.fn,
			.mobile-trigger,
			#btt,
			.woocommerce #respond input#submit, 
			.woocommerce a.button, 
			.woocommerce button.button, 
			.woocommerce input.button,
			.pagination a,
			.woocommerce ul.products li.product .price,
			.woocommerce div.product p.price, 
			.woocommerce div.product span.price,
			.woocommerce span.onsale,
			.modal-inner span {
				color: '. $headings .';
			}
			hr {
				background: '. $light .';
			}
			a,
			.image-link .inner h3 {
				color: '. $highlight .';
			}
			.post-title a:after,
			.meta a:after,
			.image-link .inner h3:after,
			.post-content a:after,
			aside a:not(.instafeed a):after {
				background: '. $highlight .';
			}
			.meta a:after {
				background: '. $headings .';
			}
			.star-rating,
			a:hover {
				color: '. $highlight .';
			}
			.btn,
			.tags a,
			input[type="submit"],
			.more-link,
			.woocommerce #respond input#submit, 
			.woocommerce a.button, 
			.woocommerce button.button, 
			.woocommerce input.button,
			.pagination a {
				border: 3px solid '. $highlight .';
				color: '. $highlight .';
			}
			.btn:hover,
			.tags a:hover,
			input[type="submit"]:hover,
			aside input[type="submit"],
			.more-link:hover,
			.woocommerce #respond input#submit:hover, 
			.woocommerce a.button:hover, 
			.woocommerce button.button:hover, 
			.woocommerce input.button:hover,
			.woocommerce #respond input#submit.alt, 
			.woocommerce a.button.alt, 
			.woocommerce button.button.alt, 
			.woocommerce input.button.alt,
			.woocommerce #respond input#submit.alt:hover, 
			.woocommerce a.button.alt:hover, 
			.woocommerce button.button.alt:hover, 
			.woocommerce input.button.alt:hover,
			.pagination a:hover {
				color: '. $white .';
			}
			.btn:before,
			.more-link:before,
			.tags a:before,
			.pagination a:before {
				background: '. $highlight .';
			}
			input[type="submit"] {
				background: '. $highlight .';
				color: '. $white .';
			}
			blockquote,
			pre {
				background: '. $grey .';
				border-left: 3px solid '. $body .';
			}
			blockquote:hover,
			pre:hover {
				border-color: '. $highlight .';
			}
			strong, 
			b,
			dt,
			#main-nav ul li a {
				color: '. $headings .';
			}
			blockquote em,
			blockquote cite {
				color: '. $body .';
			}
			code {
				color: '. $headings .';
			}
			p code {
				background: '. $grey .';
			}
			.meta,
			.widget-title {
				color: '. $headings .';
			}
			.meta a {
				color: '. $headings .';
			}
			#main-nav {
				 border-top: 1px solid '. $light .';
			}
			#main-nav ul li a {
				border-bottom: 1px solid '. $light .';
			}
			#main-nav ul li a:hover,
			#main-nav ul li.current-menu-item > a {
				color: '. $white .';
				border-color: '. $highlight .';
				background: '. $highlight .'
			}
			#main-nav ul ul {
				background: '. $white .';
			}
			#main-nav ul ul ul {
				border-left: 1px solid '. $light .';
			}
			#main-nav input {
				background: '. $white .';
			}
			#main-header {
				background: '. $white .';
				border-right: 1px solid '. $light .';
			}
			#header-trigger {
				color: '. $headings .';
				background: '. $white .';
				border-right: 1px solid '. $light .';
				border-bottom: 1px solid '. $light .';
			}
			.image-link .inner {
				background: rgba('. $white_rgb .',0.95);
			}
			.owl-carousel:before {
				background: '. $grey .';
			}
			.grid .inner {
				background: '. $white .';
			}
			.inner .bottom {
				border-top: 3px solid '. $light .';
			}
			.post-classic .inner {
				background: '. $white .';
			}
			.single .inner,
			.page .inner,
			.error404 .inner {
				background: '. $white .';
			}
			.tags {
				border-top: 3px solid '. $light .';
			}
			.post-nav:after {
				background: '. $light .';
			}
			.inner.related {
				border: 3px solid '. $highlight .';
			}
			.related .post-title {
				color: '. $highlight .';
			}
			.tiles figure:after {
				background: rgba('. $white_rgb .',0.2);
			}
			.post-slider:after {
				background: '. $grey .'
			}
			.caption-overlay .grid .inner {
				background: rgba('. $white_rgb .',0.95);
			}
			.owl-dot {
				background: rgba('. $black_rgb .'0.2);
			}
			.owl-dot.active,
			.owl-dot:hover {
				background: rgba('. $black_rgb .'0.4);
			}
			.owl-prev,
			.owl-next {
				color: '. $headings .';
			}
			.archive-title {
				background: '. $white .';
			}
			table#wp-calendar {
				border: 1px solid '. $highlight .'
			}
			table#wp-calendar thead>tr>th { 
				border: 1px solid '. $highlight .';
			}
			table#wp-calendar tbody>tr>td {
				border: 1px solid '. $highlight .';
			}
			table tr,
			table td,
			#wp-calendar table tr,
			#wp-calendar table td {
				border: 1px solid '. $light .';
			}
			table tr:nth-child(even),
			table thead tr {
				background: '. $grey .';
			}
			aside table tr:nth-child(even),
			aside table thead tr {
				background: '. $white .';
			}
			.instafeed li:before {
				background: rgba('. $white_rgb .',0.3);
			}
			.instafeed > a {
				background: rgba('. $black_rgb .'0.5);
				color: '. $white .';
			}
			.instafeed > a:hover {
				background: rgba('. $black_rgb .'0.8);
			}
			.twitter-feed .owl-dots .owl-dot {
				background: rgba('. $black_rgb .'0.2);
			}
			.twitter-feed .owl-dots .owl-dot.active, .twitter-feed .owl-dots .owl-dot:hover {
				background: rgba('. $black_rgb .'0.4);
			}
			input,
			textarea {
				background: '. $grey .';
			}
			input:focus,
			textarea:focus {
				border-bottom: 3px solid '. $highlight .';
			}
			.widget form.wpcf7-form {
				border: 3px solid '. $highlight .';
			}
			.widget form.wpcf7-form input:not(input[type="submit"]),
			.woocommerce-breadcrumb {
				background: '. $white .';
			}
			.woocommerce ul.products li.product, 
			.woocommerce-page ul.products li.product {
				background: '. $white .';
			}
			.woocommerce div.product .woocommerce-tabs .panel {
				background: '. $white .';
			}
			.woocommerce span.onsale,
			.woocommerce ul.products li.product .onsale {
				color: '. $white .';
				background: '. $highlight .';
			}
			@media (max-width: 1150px) {
				#main-header:after {
					background: '. $white .';
				}
			}
		';
		$custom_css .= get_option( 'custom_css' );
		
		//Add custom CSS ability
		wp_add_inline_style( 'ebor-style', $custom_css );
		
		/**
		 * localize script
		 */
		$script_data = array( 
			'access_token'       => get_option( 'instagram_token', '' ),
			'client_id'          => get_option( 'instagram_client', '' )
		);
		wp_localize_script( 'ebor-scripts', 'wp_data', $script_data );
		
	}
	add_action( 'wp_enqueue_scripts', 'ebor_load_scripts', 110 );
}

/**
 * Ebor Load Admin Scripts
 * Properly Enqueues Scripts & Styles for the theme
 * 
 * @since version 1.0
 * @author TommusRhodus
 */
if(!( function_exists('ebor_admin_load_scripts') )){
	function ebor_admin_load_scripts(){
		wp_enqueue_style( 'ebor-theme-admin-css', EBOR_THEME_DIRECTORY . 'admin/ebor-theme-admin.css' );
		wp_enqueue_script( 'ebor-theme-admin-js', EBOR_THEME_DIRECTORY . 'admin/ebor-theme-admin.js', array('jquery'), false, true  );
		wp_enqueue_style( 'ebor-fonts', EBOR_THEME_DIRECTORY . 'style/type/icons.css' );
	}
	add_action('admin_enqueue_scripts', 'ebor_admin_load_scripts', 200);
}