<?php 

/**
 * Load Theme Support on Init
 * Defines content width & adds editor styles
 * 
 * @since 1.0.0
 * @author TommusRhodus
 * @package acomb
 */
if(!( function_exists( 'ebor_add_editor_styles' ) )){
	function ebor_add_editor_styles() {
		
		/**
		 * Add WP Editor Styling
		 */
	    add_editor_style( 'editor-style.css' );
	    
	    /**
	     * Set Content Width
	     */
	    global $content_width;
	    if ( ! isset( $content_width ) ){ 
	    	$content_width = 1170;
	    }
	    
	}
	add_action( 'init', 'ebor_add_editor_styles', 10 );
}

/**
 * Load Theme Support after_theme_setup
 * 
 * @since 1.0.0
 * @author TommusRhodus
 * @package acomb
 */
if(!( function_exists( 'ebor_add_theme_support' ) )){
	function ebor_add_theme_support() {
		
		/**
		 * Add post thumbnail (featured image) support
		 */
		add_theme_support( 'post-thumbnails' );

		/**
		 * Add Custom Background Support and Set Default
		 */
		add_theme_support( 'custom-background', array( 'default-color' => '#f7f7f7' ) );
		
		/**
		 * Image Sizes used in the theme
		 */
		add_image_size( 'admin-list-thumb', 60, 60, true );
		add_image_size( 'preview', 600, 320, true );
		add_image_size( 'preview-masonry', 600, 9999, false );
		
		/**
		 * Add feed link support
		 */
		add_theme_support( 'automatic-feed-links' );
		
		/**
		 * Add html5 support
		 */
		add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form' ) );
		
		/**
		 * Load Translation Files
		 */
		load_theme_textdomain('acomb', trailingslashit(get_template_directory()) . 'languages');
		
		/**
		 * Add title tag support
		 */
		add_theme_support( 'title-tag' );
		
		/**
		 * Woocommerce support
		 */
		add_theme_support( 'woocommerce' );

		/**
		 * Gutenberg
		 */
		add_theme_support( 'align-wide' );
		add_theme_support( 'wp-block-styles' );
		
	}
	add_action('after_setup_theme', 'ebor_add_theme_support', 10 );
}